==> librenms-24.8.1v0.tgz: librenms/lang/pt-BR/map.php <==
<?php

return [
    'custom' => [
        'title' => [
            'edit_dialog' => 'Selecionar Mapa Personalizado para Editar',
            'create' => 'Criar Novo Mapa Personalizado',
            'view' => ':name | Mapa Personalizado',
            'edit' => 'Editar Mapa Personalizado',
            'manage' => 'Gerenciar Mapas Personalizados',
        ],
        'create_map' => 'Novo Mapa',
        'view' => [
            'loading' => 'Carregando dados',
            'no_devices' => 'Nenhum dispositivo encontrado',
        ],
        'edit' => [
            'text_font' => 'Fonte do Texto',
            'text_size' => 'Tamanho do Texto',
            'text_color' => 'Cor do Texto',
            'defaults' => 'Definir Padrões',
            'bg' => [
                'title' => 'Definir Plano de Fundo',
                'background' => 'Plano de Fundo',
                'color' => 'Cor',
                'image' => 'Imagem',
                'map' => 'Mapa',
                'none' => 'Nenhum',
                'clear_bg' => 'Limpar Plano de Fundo',
                'clear_background' => 'Limpar Plano de Fundo',
                'keep_background' => 'Manter Plano de Fundo',
                'saving' => 'Salvando...',
                'save_errors' => 'Falha ao salvar devido aos seguintes erros:',
                'save_error' => 'Falha ao salvar. O servidor retornou o código de erro: :code',
                'save' => 'Salvar Plano de Fundo',
                'lat' => 'Latitude',
                'lng' => 'Longitude',
                'zoom' => 'Zoom',
                'adjust_map' => 'Ajustar Mapa',
                'adjust_map_finish' => 'Concluir Ajuste do Mapa',
                'as_image' => 'Definir como Imagem',
                'as_image_hint' => 'Definir o mapa como plano de fundo da imagem será estático, mas terá desempenho melhor e funcionará sem conexão com o servidor de mapas',
            ],
            'map' => [
                'settings_title' => 'Configurações do Mapa',
                'name' => 'Nome',
                'menu_group' => 'Menu Grupo',
                'no_group' => 'Sem Grupo',
                'width' => 'Largura',
                'height' => 'Altura',
                'alignment' => 'Alinhamento do Nó',
                'edgeseparation' => 'Separação de Links',
                'reverse' => 'Inverter Setas',
                'enable_legend' => 'Habilitar Legenda',
                'saving' => 'Salvando...',
                'save_errors' => 'Falha ao salvar devido aos seguintes erros:',
                'save_error' => 'Falha ao salvar. O servidor retornou o código de erro: :code',
                'delete' => 'Excluir :name?',
                'list' => 'Retornar à lista de mapas',
                'unsavedchanges' => 'Você tem alterações não salvas. Pressione confirmar para descartar as alterações e retornar à lista de mapas, ou cancelar para retornar ao editor.',
                'edit' => 'Editar Configurações do Mapa',
                'rerender' => 'Re-Renderizar Mapa',
                'save' => 'Salvar Mapa',
                'legend' => [
                    'font_size' => 'Tamanho do Texto da Legenda',
                    'steps' => 'Etapas da Legenda',
                    'hideinvalid' => 'Ocultar Inválidos',
                    'hideoverspeed' => 'Ocultar 100%+',
                ],
            ],
            'node' => [
                'new' => 'Novo Nó',
                'add' => 'Adicionar Nó',
                'edit' => 'Editar Nó',
                'defaults_title' => 'Configuração Padrão do Nó',
                'label' => 'Rótulo',
                'name' => 'Nome do Nó',
                'device_select' => 'Selecionar Dispositivo',
                'edit_defaults' => 'Editar Padrões do Nó',
                'map_link' => 'Link para Mapa',
                'map_select' => 'Selecionar Mapa...',
                'style' => 'Estilo',
                'style_options' => [
                    'box' => 'Caixa',
                    'circle' => 'Círculo',
                    'database' => 'Banco de Dados',
                    'ellipse' => 'Elipse',
                    'text' => 'Texto',
                    'device_image' => 'Imagem do Dispositivo',
                    'device_image_circle' => 'Imagem do Dispositivo (Circular)',
                    'diamond' => 'Diamante',
                    'dot' => 'Ponto',
                    'star' => 'Estrela',
                    'triangle' => 'Triângulo',
                    'triangle_inverted' => 'Triângulo Invertido',
                    'hexagon' => 'Hexágono',
                    'square' => 'Quadrado',
                    'icon' => 'Ícone (selecionar abaixo)',
                ],
                'icon' => 'Ícone',
                'icon_options' => [
                    'server' => 'Servidor',
                    'desktop' => 'Desktop',
                    'dish' => 'Antena Parabólica',
                    'satellite' => 'Satélite',
                    'wifi' => 'Wifi',
                    'cloud' => 'Nuvem',
                    'globe' => 'Globo',
                    'tower' => 'Torre',
                    'arrow_right' => 'Seta - Direita',
                    'arrow_left' => 'Seta - Esquerda',
                    'arrow_up' => 'Seta - Cima',
                    'arrow_down' => 'Seta - Baixo',
                ],
                'image' => 'Imagem',
                'image_options' => [
                    'adc' => 'Controlador de Entrega de Aplicação',
                    'firewall' => 'Firewall',
                    'gtm' => 'Gerenciador de Tráfego Global',
                    'router' => 'Roteador',
                    'switch-l2' => 'Switch - L2',
                    'switch-l3' => 'Switch - L3',
                ],
                'size' => 'Tamanho do Nó',
                'bg_color' => 'Cor de Fundo',
                'border_color' => 'Cor da Borda',
            ],
            'edge' => [
                'new' => 'Nova Aresta',
                'add' => 'Adicionar Aresta',
                'defaults_title' => 'Configuração Padrão da Aresta',
                'from' => 'De',
                'to' => 'Para',
                'port_select' => 'Selecionar Porta',
                'reverse' => 'Inverter Direção da Porta',
                'edit_defaults' => 'Editar Padrões da Aresta',
                'style' => 'Estilo da Linha',
                'style_options' => [
                    'dynamic' => 'Dinâmico',
                    'continuous' => 'Contínuo',
                    'discrete' => 'Discreto',
                    'diagonalCross' => 'Cruz Diagonal',
                    'straightCross' => 'Cruz Reta',
                    'horizontal' => 'Horizontal',
                    'vertical' => 'Vertical',
                    'curvedCW' => 'Curvado no Sentido Horário',
                    'curvedCCW' => 'Curvado no Sentido Anti-Horário',
                    'cubicBezier' => 'Bezier Cúbico',
                ],
                'show_usage_percent' => 'Mostrar percentual de uso',
                'show_usage_bps' => 'Mostrar uso em bps',
                'label' => 'Rótulo',
                'recenter' => 'Recentrar Linha',
            ],
            'validate' => [
                'width_format' => 'A largura deve ser um número seguido de px ou %',
                'width_percent' => 'A largura em porcentagem deve estar entre 10 e 100',
                'width_pixels' => 'A largura em pixels deve ser de pelo menos 200',
                'height_format' => 'A altura deve ser um número seguido de px ou %',
                'height_percent' => 'A altura em porcentagem deve estar entre 10 e 100',
                'height_pixels' => 'A altura em pixels deve ser de pelo menos 200',
            ],
        ],
    ],
];

==> librenms-25.8.0v0.tgz: librenms/lang/pt-BR/map.php <==
<?php

return [
    'custom' => [
        'title' => [
            'edit_dialog' => 'Selecione um Mapa Personalizado para Editar',
            'create' => 'Criar Novo Mapa Personalizado',
            'view' => ':name | Mapa Personalizado',
            'edit' => 'Editar Mapa Personalizado',
            'manage' => 'Gerenciar Mapas Personalizados',
        ],
        'create_map' => 'Novo Mapa',
        'view' => [
            'loading' => 'Carregando dados',
            'no_devices' => 'Nenhum dispositivo encontrado',
        ],
        'nodeimage' => [
            'delete' => 'Excluir Imagem',
            'upload' => 'Subir Imagem',
            'name' => 'Nome da Imagem',
            'new' => 'Nova Imagem',
            'title' => [
                'edit' => 'Editar Imagem de Nó',
                'manage' => 'Gerenciar Imagens de Nó',
                'new' => 'Nova Imagem de Nó',
            ],
        ],
        'edit' => [
            'text_font' => 'Fonte do Texto',
            'text_size' => 'Tamanho do Texto',
            'text_color' => 'Cor do Texto',
            'defaults' => 'Definir Padrões',
            'bg' => [
                'title' => 'Definir Plano de Fundo',
                'background' => 'Plano de Fundo',
                'color' => 'Cor',
                'image' => 'Imagem',
                'map' => 'Mapa',
                'none' => 'Nenhum',
                'clear_bg' => 'Limpar Plano de Fundo',
                'clear_background' => 'Limpar Plano de Fundo',
                'keep_background' => 'Manter Plano de Fundo',
                'saving' => 'Salvando...',
                'save_errors' => 'Falha ao salvar devido aos seguintes erros:',
                'save_error' => 'Falha ao salvar. O servidor retornou o código de erro: :code',
                'save' => 'Salvar Plano de Fundo',
                'lat' => 'Latitude',
                'lng' => 'Longitude',
                'zoom' => 'Zoom',
                'adjust_map' => 'Ajustar Mapa',
                'adjust_map_finish' => 'Concluir Ajuste do Mapa',
                'as_image' => 'Definir como Imagem',
                'as_image_hint' => 'Definir o mapa como plano de fundo da imagem será estático, mas terá desempenho melhor e funcionará sem conexão com o servidor de mapas',
            ],
            'map' => [
                'settings_title' => 'Configurações do Mapa',
                'selectall' => 'Selecionar Todos',
                'name' => 'Nome',
                'menu_group' => 'Grupo',
                'multiselect_info' => 'Clique e segure ou mantenha pressionada a tecla Ctrl para selecionar vários nós.',
                'no_group' => 'Sem Grupo',
                'width' => 'Largura',
                'height' => 'Altura',
                'alignment' => 'Alinhamento do Nó',
                'edgeseparation' => 'Separação de Links',
                'reverse' => 'Inverter Setas',
                'enable_legend' => 'Habilitar Legenda',
                'saving' => 'Salvando...',
                'save_errors' => 'Falha ao salvar devido aos seguintes erros:',
                'save_error' => 'Falha ao salvar. O servidor retornou o código de erro: :code',
                'delete' => 'Excluir :name?',
                'list' => 'Retornar à lista de mapas',
                'unsavedchanges' => 'Você tem alterações não salvas. Pressione confirmar para descartar as alterações e retornar à lista de mapas, ou cancelar para retornar ao editor.',
                'edit' => 'Editar Configurações do Mapa',
                'rerender' => 'Re-Renderizar Mapa',
                'save' => 'Salvar Mapa',
                'legend' => [
                    'customcolours' => 'Cores Personalizadas',
                    'colour' => 'Cor',
                    'colour_lower_pct' => 'Porcentagem Inicial',
                    'colour_down' => 'Cor para Dispositivo Inativo',
                    'colour_invalid' => 'Cor para Percentual Desconhecido',
                    'font_size' => 'Tamanho do Texto da Legenda',
                    'steps' => 'Passo da Legenda',
                    'hideinvalid' => 'Ocultar Inválidos',
                    'hideoverspeed' => 'Ocultar 100%+',
                ],
                'legend_title' => 'Configurações da Legenda',
                'legend_toggle' => 'Alternar LEgenda',
                'zoom' => 'Pan e Zoom',
                'dragnodes' => 'Mover Nós',
                'physics' => 'Motor de Física',
            ],
            'node' => [
                'new' => 'Novo Nó',
                'add' => 'Adicionar Nó',
                'edit' => 'Editar Nó',
                'defaults_title' => 'Configuração Padrão do Nó',
                'label' => 'Rótulo',
                'name' => 'Nome do Nó',
                'device_select' => 'Selecionar Dispositivo',
                'edit_defaults' => 'Editar Padrões do Nó',
                'map_link' => 'Link para Mapa',
                'map_select' => 'Selecionar Mapa...',
                'style' => 'Estilo',
                'style_options' => [
                    'box' => 'Caixa',
                    'circle' => 'Círculo',
                    'database' => 'Banco de Dados',
                    'ellipse' => 'Elipse',
                    'text' => 'Texto',
                    'device_image' => 'Imagem do Dispositivo',
                    'device_image_circle' => 'Imagem do Dispositivo (Circular)',
                    'diamond' => 'Diamante',
                    'dot' => 'Ponto',
                    'star' => 'Estrela',
                    'triangle' => 'Triângulo',
                    'triangle_inverted' => 'Triângulo Invertido',
                    'hexagon' => 'Hexágono',
                    'square' => 'Quadrado',
                    'icon' => 'Ícone (selecionar abaixo)',
                ],
                'icon' => 'Ícone',
                'icon_options' => [
                    'server' => 'Servidor',
                    'desktop' => 'Desktop',
                    'dish' => 'Antena Parabólica',
                    'satellite' => 'Satélite',
                    'wifi' => 'Wifi',
                    'cloud' => 'Nuvem',
                    'globe' => 'Globo',
                    'tower' => 'Torre',
                    'arrow_right' => 'Seta - Direita',
                    'arrow_left' => 'Seta - Esquerda',
                    'arrow_up' => 'Seta - Cima',
                    'arrow_down' => 'Seta - Baixo',
                ],
                'image' => 'Imagem',
                'image_options' => [
                    'adc' => 'Controlador de Entrega de Aplicação',
                    'firewall' => 'Firewall',
                    'gtm' => 'Gerenciador de Tráfego Global',
                    'router' => 'Roteador',
                    'switch-l2' => 'Switch - L2',
                    'switch-l3' => 'Switch - L3',
                ],
                'size' => 'Tamanho do Nó',
                'bg_color' => 'Cor de Fundo',
                'border_color' => 'Cor da Borda',
            ],
            'edge' => [
                'new' => 'Novo Link',
                'add' => 'Adicionar Link',
                'edit' => 'Editar Link',
                'defaults_title' => 'Configurações Padrão dos Links',
                'dynamic_width' => 'Largura Dinâmica',
                'fixed_width' => 'Largura Fixa',
                'from' => 'De',
                'to' => 'Para',
                'port_select' => 'Selecionar Porta',
                'reverse' => 'Inverter Direção da Porta',
                'edit_defaults' => 'Editar Padrões da Aresta',
                'style' => 'Estilo da Linha',
                'style_options' => [
                    'dynamic' => 'Dinâmico',
                    'continuous' => 'Contínuo',
                    'discrete' => 'Discreto',
                    'diagonalCross' => 'Cruz Diagonal',
                    'straightCross' => 'Cruz Reta',
                    'horizontal' => 'Horizontal',
                    'vertical' => 'Vertical',
                    'curvedCW' => 'Curvado no Sentido Horário',
                    'curvedCCW' => 'Curvado no Sentido Anti-Horário',
                    'cubicBezier' => 'Bezier Cúbico',
                ],
                'show_usage_percent' => 'Mostrar percentual de uso',
                'show_usage_bps' => 'Mostrar uso em bps',
                'text_align' => 'Alinhamento do Texto',
                'align_options' => [
                    'horizontal' => 'Horizontal',
                    'top' => 'Topo',
                    'middle' => 'Meio',
                    'bottom' => 'Fundo',
                ],
                'label' => 'Etiqueta',
                'recenter' => 'Recentralizar Linha',
            ],
            'validate' => [
                'width_format' => 'A largura deve ser um número seguido de px ou %',
                'width_percent' => 'A largura em porcentagem deve estar entre 10 e 100',
                'width_pixels' => 'A largura em pixels deve ser de pelo menos 200',
                'height_format' => 'A altura deve ser um número seguido de px ou %',
                'height_percent' => 'A altura em porcentagem deve estar entre 10 e 100',
                'height_pixels' => 'A altura em pixels deve ser de pelo menos 200',
            ],
        ],
        'widget' => [
            'not_found' => 'Nenhum mapa selecionado. Edite o widget para selecionar um mapa.',
        ],
    ],
];
